@@ -48,6 +48,35 @@ class DeploymentConfig:
     metadata: Dict[str, Any] = field(default_factory=dict)
 
 
+@dataclass  
+class LocalGPUGlobalConfig:
+    """Global configuration for local GPU deployment"""
+    enable_local_gpu: bool = True
+    auto_detect_gpu: bool = True
+    workspace_dir: str = "./local_deployments"
+    preferred_backend: str = "transformers"  # vllm, tensorrt_llm, transformers
+    
+    # Default resource settings
+    default_gpu_memory_fraction: float = 0.9
+    default_max_batch_size: int = 8
+    default_max_model_len: int = 2048
+    default_precision: str = "float16"
+    
+    # Health monitoring
+    health_check_interval: int = 30  # seconds
+    auto_restart_unhealthy: bool = True
+    max_consecutive_failures: int = 3
+    
+    # Service limits
+    max_concurrent_services: int = 3
+    max_services_per_gpu: int = 2
+    
+    # Performance settings
+    enable_model_compilation: bool = True
+    enable_memory_optimization: bool = True
+    cleanup_on_shutdown: bool = True
+
+
 @dataclass
 class GlobalConfig:
     """Global configuration settings"""
@@ -79,6 +108,18 @@ class GlobalConfig:
     enable_model_cache: bool = True
     cache_size_gb: int = 50
     cache_cleanup_interval: int = 3600  # 1 hour
+    
+    # Local GPU settings
+    enable_local_gpu: bool = True
+    local_gpu_memory_fraction: float = 0.9
+    local_workspace_dir: str = "./local_deployments"
+    auto_detect_gpu: bool = True
+    preferred_local_backend: str = "transformers"  # vllm, tensorrt_llm, transformers
+    
+    # Local service defaults
+    local_health_check_interval: int = 30  # seconds
+    local_auto_restart_unhealthy: bool = True
+    local_max_concurrent_services: int = 3
 
 
 class ConfigManager:
@@ -121,6 +162,7 @@ class ConfigManager:
         """Initialize configuration manager"""
         if not self._initialized:
             self.global_config = GlobalConfig()
+            self.local_gpu_config = LocalGPUGlobalConfig()
             self.provider_configs: Dict[str, ProviderConfig] = {}
             self.deployment_configs: Dict[str, DeploymentConfig] = {}
             
@@ -153,6 +195,7 @@ class ConfigManager:
         env_files = [
             project_root / ".env",
             project_root / ".env.local",
+            project_root / "deployment" / "dev" / ".env",
             Path.cwd() / ".env",
         ]
         
@@ -197,6 +240,38 @@ class ConfigManager:
             for key, value in global_settings.items():
                 if hasattr(self.global_config, key):
                     setattr(self.global_config, key, value)
+        
+        # Load database configuration from environment
+        # Check multiple possible environment variable names for compatibility
+        supabase_url = os.getenv("SUPABASE_URL") or os.getenv("SUPABASE_LOCAL_URL")
+        supabase_key = os.getenv("SUPABASE_ANON_KEY") or os.getenv("SUPABASE_LOCAL_ANON_KEY")
+        
+        if supabase_url and supabase_key:
+            self.global_config.use_supabase = True
+            self.global_config.supabase_url = supabase_url
+            self.global_config.supabase_key = supabase_key
+            logger.debug(f"Supabase configured: URL={supabase_url[:30]}...")
+        else:
+            # Check if explicitly disabled
+            use_supabase_env = os.getenv("ISA_USE_SUPABASE", "").lower()
+            if use_supabase_env == "false":
+                self.global_config.use_supabase = False
+            logger.debug("Supabase not configured, using default storage")
+        
+        # Load local GPU configuration
+        local_gpu_settings = {
+            "enable_local_gpu": os.getenv("ISA_ENABLE_LOCAL_GPU", "true").lower() == "true",
+            "auto_detect_gpu": os.getenv("ISA_AUTO_DETECT_GPU", "true").lower() == "true",
+            "workspace_dir": os.getenv("ISA_LOCAL_WORKSPACE_DIR", "./local_deployments"),
+            "preferred_backend": os.getenv("ISA_PREFERRED_LOCAL_BACKEND", "transformers"),
+            "default_gpu_memory_fraction": float(os.getenv("ISA_GPU_MEMORY_FRACTION", "0.9")),
+            "health_check_interval": int(os.getenv("ISA_LOCAL_HEALTH_CHECK_INTERVAL", "30")),
+            "max_concurrent_services": int(os.getenv("ISA_MAX_CONCURRENT_SERVICES", "3")),
+        }
+        
+        for key, value in local_gpu_settings.items():
+            if hasattr(self.local_gpu_config, key):
+                setattr(self.local_gpu_config, key, value)
     
     def _load_provider_configs(self):
         """Load provider configurations from environment"""
@@ -310,6 +385,21 @@ class ConfigManager:
         """Get configuration for a specific deployment platform"""
         return self.deployment_configs.get(platform.value)
     
+    def get_local_gpu_config(self) -> LocalGPUGlobalConfig:
+        """Get local GPU global configuration"""
+        return self.local_gpu_config
+    
+    def is_local_gpu_enabled(self) -> bool:
+        """Check if local GPU deployment is enabled and available"""
+        if not self.local_gpu_config.enable_local_gpu:
+            return False
+        
+        try:
+            from ..utils.gpu_utils import check_cuda_availability
+            return check_cuda_availability()
+        except ImportError:
+            return False
+    
     def is_provider_enabled(self, provider: Provider) -> bool:
         """Check if a provider is enabled and configured"""
         config = self.get_provider_config(provider)
