@@ -41,6 +41,38 @@ class ProviderConfig:
     models: List[Dict[str, Any]] = field(default_factory=list)
     metadata: Dict[str, Any] = field(default_factory=dict)
 
+@dataclass
+class ConsulConfig:
+    """Consul service discovery configuration"""
+    enabled: bool = True
+    host: str = "localhost"
+    port: int = 8500
+    timeout: int = 10
+    
+@dataclass
+class ServiceConfig:
+    """Service endpoint configuration with Consul discovery support"""
+    # Enable Consul discovery
+    use_consul_discovery: bool = True
+    
+    # Fallback URLs when Consul is unavailable
+    mcp_base_url: str = "http://localhost:8081"
+    ollama_base_url: str = "http://localhost:11434"
+    influxdb_url: str = "http://localhost:8086"
+    loki_url: str = "http://localhost:3100"
+    minio_endpoint: str = "localhost:9000"
+    redis_url: str = "redis://localhost:6379"
+    api_port: int = 8000
+    redis_port: int = 6379
+    
+    # Consul service names for discovery
+    mcp_service_name: str = "mcp"
+    ollama_service_name: str = "ollama"
+    influxdb_service_name: str = "influxdb"
+    loki_service_name: str = "loki"
+    minio_service_name: str = "minio"
+    redis_service_name: str = "redis"
+
 @dataclass
 class DatabaseConfig:
     """Database configuration"""
@@ -50,6 +82,7 @@ class DatabaseConfig:
     supabase_schema: Optional[str] = None
     fallback_to_sqlite: bool = False
     sqlite_path: str = "./isa_model.db"
+    default_database_url: str = "postgresql://postgres:postgres@127.0.0.1:54322/postgres?options=-c%20search_path%3Ddev"
     connection_pool_size: int = 10
     max_retries: int = 3
 
@@ -110,6 +143,8 @@ class GlobalConfig:
     debug: bool = False
     
     # Component configurations
+    consul: ConsulConfig = field(default_factory=ConsulConfig)
+    services: ServiceConfig = field(default_factory=ServiceConfig)
     database: DatabaseConfig = field(default_factory=DatabaseConfig)
     deployment: DeploymentConfig = field(default_factory=DeploymentConfig)
     api: APIConfig = field(default_factory=APIConfig)
@@ -143,8 +178,10 @@ class ConfigManager:
             self.global_config: Optional[GlobalConfig] = None
             self.provider_configs: Dict[str, ProviderConfig] = {}
             self.model_definitions: Dict[str, Dict[str, Any]] = {}
+            self._consul_discovery = None
             
             self._load_configuration()
+            self._initialize_consul_discovery()
             ConfigManager._initialized = True
     
     def _load_configuration(self):
@@ -220,6 +257,8 @@ class ConfigManager:
             self.global_config = GlobalConfig(
                 environment=environment,
                 debug=env_data.get('debug', False),
+                consul=ConsulConfig(**env_data.get('consul', {})),
+                services=ServiceConfig(**env_data.get('services', {})),
                 database=DatabaseConfig(**env_data.get('database', {})),
                 deployment=DeploymentConfig(**env_data.get('deployment', {})),
                 api=APIConfig(**env_data.get('api', {})),
@@ -265,6 +304,10 @@ class ConfigManager:
                 "api_key": ["YYDS_API_KEY"],
                 "api_base_url": ["YYDS_API_BASE", "YYDS_BASE_URL"],
             },
+            Provider.CEREBRAS: {
+                "api_key": ["CEREBRAS_API_KEY"],
+                "api_base_url": ["CEREBRAS_API_BASE", "CEREBRAS_BASE_URL"],
+            },
         }
         
         for provider, env_vars in provider_env_mapping.items():
@@ -344,7 +387,9 @@ class ConfigManager:
         # This can be enhanced later with deployment-specific YAML files
         deployment_env_mapping = {
             DeploymentPlatform.MODAL: {
-                "api_key": ["MODAL_TOKEN"],
+                "token_id": ["MODAL_TOKEN_ID"],
+                "token_secret": ["MODAL_TOKEN_SECRET"],
+                "environment": ["MODAL_ENVIRONMENT"],
                 "endpoint": ["MODAL_ENDPOINT"],
             },
             DeploymentPlatform.RUNPOD: {
@@ -428,6 +473,92 @@ class ConfigManager:
             
         logger.debug(f"Database configured for {env}: schema={schema}, url={supabase_url}")
     
+    def _initialize_consul_discovery(self):
+        """Initialize Consul service discovery client"""
+        if not self.global_config or not self.global_config.consul.enabled:
+            logger.info("Consul discovery disabled")
+            return
+            
+        try:
+            from ..discovery.consul_discovery import ConsulServiceDiscovery
+            self._consul_discovery = ConsulServiceDiscovery(
+                consul_host=self.global_config.consul.host,
+                consul_port=self.global_config.consul.port
+            )
+            
+            if self._consul_discovery.is_available():
+                logger.info("Consul service discovery initialized successfully")
+            else:
+                logger.warning("Consul not available, using fallback URLs")
+                self._consul_discovery = None
+                
+        except ImportError as e:
+            logger.warning(f"Consul discovery not available: {e}")
+            self._consul_discovery = None
+        except Exception as e:
+            logger.error(f"Failed to initialize Consul discovery: {e}")
+            self._consul_discovery = None
+    
+    def _apply_service_env_overrides(self):
+        """Apply service endpoint environment variable overrides"""
+        if not self.global_config:
+            return
+            
+        # Consul configuration overrides
+        consul_env_mapping = {
+            "enabled": ["CONSUL_ENABLED"],
+            "host": ["CONSUL_HOST"],
+            "port": ["CONSUL_PORT"],
+        }
+        
+        for setting, env_vars in consul_env_mapping.items():
+            for env_var in env_vars:
+                value = os.getenv(env_var)
+                if value:
+                    if setting == "enabled":
+                        setattr(self.global_config.consul, setting, value.lower() == "true")
+                    elif setting == "port":
+                        try:
+                            setattr(self.global_config.consul, setting, int(value))
+                        except ValueError:
+                            continue
+                    else:
+                        setattr(self.global_config.consul, setting, value)
+                    break
+        
+        # Service endpoint overrides
+        service_env_mapping = {
+            "use_consul_discovery": ["USE_CONSUL_DISCOVERY"],
+            "mcp_base_url": ["MCP_BASE_URL", "MCP_URL"],
+            "ollama_base_url": ["OLLAMA_BASE_URL", "OLLAMA_URL"],
+            "influxdb_url": ["INFLUXDB_URL", "INFLUX_URL"],
+            "loki_url": ["LOKI_URL"],
+            "minio_endpoint": ["MINIO_ENDPOINT", "MINIO_HOST"],
+            "redis_url": ["REDIS_URL"],
+            "redis_port": ["REDIS_PORT"],
+            "mcp_service_name": ["MCP_SERVICE_NAME"],
+            "ollama_service_name": ["OLLAMA_SERVICE_NAME"],
+            "influxdb_service_name": ["INFLUXDB_SERVICE_NAME"],
+            "loki_service_name": ["LOKI_SERVICE_NAME"],
+            "minio_service_name": ["MINIO_SERVICE_NAME"],
+            "redis_service_name": ["REDIS_SERVICE_NAME"],
+        }
+        
+        for setting, env_vars in service_env_mapping.items():
+            for env_var in env_vars:
+                value = os.getenv(env_var)
+                if value:
+                    if setting == "use_consul_discovery":
+                        setattr(self.global_config.services, setting, value.lower() == "true")
+                    elif setting in ["redis_port"]:
+                        try:
+                            setattr(self.global_config.services, setting, int(value))
+                        except ValueError:
+                            continue
+                    else:
+                        setattr(self.global_config.services, setting, value)
+                    break
+    
     def _apply_env_overrides(self):
         """Apply environment variable overrides"""
         if not self.global_config:
@@ -436,13 +567,15 @@ class ConfigManager:
         # Environment-based database configuration
         self._configure_database_for_environment()
         
-        # Other overrides
+        # Service configuration overrides
+        self._apply_service_env_overrides()
         
         # Serving overrides
-        port_env = os.getenv("PORT")
+        port_env = os.getenv("PORT") or os.getenv("API_PORT")
         if port_env:
             try:
                 self.global_config.serving.port = int(port_env)
+                self.global_config.services.api_port = int(port_env)
             except ValueError:
                 pass
         
@@ -458,6 +591,100 @@ class ConfigManager:
             raise RuntimeError("Configuration not loaded")
         return self.global_config
     
+    def get_service_config(self) -> ServiceConfig:
+        """Get service configuration"""
+        if not self.global_config:
+            raise RuntimeError("Configuration not loaded")
+        return self.global_config.services
+    
+    def get_consul_config(self) -> ConsulConfig:
+        """Get Consul configuration"""
+        if not self.global_config:
+            raise RuntimeError("Configuration not loaded")
+        return self.global_config.consul
+    
+    def discover_service_url(self, service_name: str, fallback_url: Optional[str] = None) -> str:
+        """Discover service URL using Consul or return fallback"""
+        if not self.global_config or not self.global_config.services.use_consul_discovery:
+            return fallback_url or self._get_fallback_service_url(service_name)
+            
+        if not self._consul_discovery or not self._consul_discovery.is_available():
+            logger.debug(f"Consul not available, using fallback for {service_name}")
+            return fallback_url or self._get_fallback_service_url(service_name)
+            
+        try:
+            discovered_url = self._consul_discovery.get_service_url(
+                service_name, 
+                fallback_url or self._get_fallback_service_url(service_name)
+            )
+            return discovered_url
+        except Exception as e:
+            logger.warning(f"Failed to discover {service_name}: {e}")
+            return fallback_url or self._get_fallback_service_url(service_name)
+    
+    def _get_fallback_service_url(self, service_name: str) -> str:
+        """Get fallback URL for service based on service name"""
+        if not self.global_config:
+            raise RuntimeError("Configuration not loaded")
+            
+        service_config = self.global_config.services
+        
+        # Map service names to fallback URLs
+        service_mapping = {
+            service_config.mcp_service_name: service_config.mcp_base_url,
+            service_config.ollama_service_name: service_config.ollama_base_url,
+            service_config.influxdb_service_name: service_config.influxdb_url,
+            service_config.loki_service_name: service_config.loki_url,
+            service_config.minio_service_name: f"http://{service_config.minio_endpoint}",
+            service_config.redis_service_name: service_config.redis_url,
+        }
+        
+        return service_mapping.get(service_name, f"http://localhost:8080")
+    
+    def get_mcp_url(self) -> str:
+        """Get MCP service URL (Consul discovery + fallback)"""
+        service_name = self.global_config.services.mcp_service_name
+        return self.discover_service_url(service_name, self.global_config.services.mcp_base_url)
+    
+    def get_ollama_url(self) -> str:
+        """Get Ollama service URL (Consul discovery + fallback)"""
+        service_name = self.global_config.services.ollama_service_name
+        return self.discover_service_url(service_name, self.global_config.services.ollama_base_url)
+    
+    def get_influxdb_url(self) -> str:
+        """Get InfluxDB service URL (Consul discovery + fallback)"""
+        service_name = self.global_config.services.influxdb_service_name
+        return self.discover_service_url(service_name, self.global_config.services.influxdb_url)
+    
+    def get_loki_url(self) -> str:
+        """Get Loki service URL (Consul discovery + fallback)"""
+        service_name = self.global_config.services.loki_service_name
+        return self.discover_service_url(service_name, self.global_config.services.loki_url)
+    
+    def get_minio_url(self) -> str:
+        """Get MinIO service URL (Consul discovery + fallback)"""
+        service_name = self.global_config.services.minio_service_name
+        fallback = f"http://{self.global_config.services.minio_endpoint}"
+        return self.discover_service_url(service_name, fallback)
+    
+    def get_redis_url(self) -> str:
+        """Get Redis service URL (Consul discovery + fallback)"""
+        service_name = self.global_config.services.redis_service_name
+        return self.discover_service_url(service_name, self.global_config.services.redis_url)
+    
+    def resolve_consul_url(self, url: str) -> str:
+        """Resolve consul:// URLs to actual service addresses"""
+        if not url or not url.startswith("consul://"):
+            return url
+            
+        if not self._consul_discovery:
+            # If Consul not available, try to extract service name and use fallback
+            parts = url.replace("consul://", "").split("/", 1)
+            service_name = parts[0]
+            return self._get_fallback_service_url(service_name)
+            
+        return self._consul_discovery.resolve_service_url(url)
+    
     def get_provider_config(self, provider: str) -> Optional[ProviderConfig]:
         """Get provider configuration"""
         return self.provider_configs.get(provider)
