@@ -150,7 +150,7 @@ class LangChainMessageAdapter:
                     tool_calls.append(tool_call)
                 
                 return AIMessage(
-                    content=response.content or "",
+                    content=response.content if response.content is not None else "",
                     tool_calls=tool_calls
                 )
             else:
@@ -177,7 +177,7 @@ class LangChainMessageAdapter:
                     }
                     tool_calls.append(tool_call)
                 
-                return SimpleAIMessage(response.content or "", tool_calls)
+                return SimpleAIMessage(response.content if response.content is not None else "", tool_calls)
             else:
                 content = response if isinstance(response, str) else getattr(response, 'content', str(response))
                 return SimpleAIMessage(content)
@@ -431,8 +431,13 @@ class StandardMessageAdapter:
         try:
             from langchain_core.messages import AIMessage
             
-            # Extract content
-            content = response if isinstance(response, str) else getattr(response, 'content', str(response))
+            # Extract content - handle None content for tool calls
+            if isinstance(response, str):
+                content = response
+            elif hasattr(response, 'content'):
+                content = response.content if response.content is not None else ""
+            else:
+                content = str(response)
             
             # Handle tool_calls if present
             if hasattr(response, 'tool_calls') and response.tool_calls:
