@@ -3,6 +3,7 @@ import httpx
 import json
 from typing import Dict, Any, List, Union, AsyncGenerator, Optional, Callable
 from isa_model.inference.services.llm.base_llm_service import BaseLLMService
+from isa_model.core.config.config_manager import ConfigManager
 
 logger = logging.getLogger(__name__)
 
@@ -16,7 +17,10 @@ class OllamaLLMService(BaseLLMService):
         provider_config = self.get_provider_config()
         
         # Create HTTP client for Ollama API
-        base_url = provider_config.get("base_url", "http://localhost:11434")
+        config_manager = ConfigManager()
+        # Use Consul discovery with fallback
+        default_base_url = config_manager.get_ollama_url()
+        base_url = provider_config.get("base_url", default_base_url)
         timeout = provider_config.get("timeout", 60)
         
         self.client = httpx.AsyncClient(
@@ -34,7 +38,10 @@ class OllamaLLMService(BaseLLMService):
         """Ensure the HTTP client is available and not closed"""
         if not hasattr(self, 'client') or not self.client or self.client.is_closed:
             provider_config = self.get_provider_config()
-            base_url = provider_config.get("base_url", "http://localhost:11434")
+            config_manager = ConfigManager()
+            # Use Consul discovery with fallback
+            default_base_url = config_manager.get_ollama_url()
+            base_url = provider_config.get("base_url", default_base_url)
             timeout = provider_config.get("timeout", 60)
             self.client = httpx.AsyncClient(base_url=base_url, timeout=timeout)
     
