@@ -20,6 +20,8 @@ class OpenAILLMService(BaseLLMService):
         
         # Check if this is an O-series reasoning model
         self.is_reasoning_model = model_name.startswith("o4-") or model_name.startswith("o3-")
+        self.uses_completion_tokens = self.is_reasoning_model or model_name.startswith("gpt-5")
+        self.requires_default_temperature = self.is_reasoning_model or model_name.startswith("gpt-5")
         self.supports_deep_research = "deep-search" in model_name or "deep-research" in model_name
         
         # Get configuration from centralized config manager
@@ -36,7 +38,9 @@ class OpenAILLMService(BaseLLMService):
             self.client = AsyncOpenAI(
                 api_key=provider_config["api_key"],
                 base_url=provider_config.get("api_base_url", "https://api.openai.com/v1"),
-                organization=provider_config.get("organization")
+                organization=provider_config.get("organization"),
+                timeout=10.0,  # 10 second timeout for first token (much faster than 600s default)
+                max_retries=2  # Retry on timeout
             )
             
             logger.info(f"Initialized OpenAILLMService with model {self.model_name} and endpoint {self.client.base_url}")
@@ -70,6 +74,8 @@ class OpenAILLMService(BaseLLMService):
         
         # Copy OpenAI-specific attributes
         bound_service.is_reasoning_model = self.is_reasoning_model
+        bound_service.uses_completion_tokens = self.uses_completion_tokens
+        bound_service.requires_default_temperature = self.requires_default_temperature
         bound_service.supports_deep_research = self.supports_deep_research
         
         # Copy base class attributes
@@ -103,7 +109,7 @@ class OpenAILLMService(BaseLLMService):
         
         return bound_service
     
-    async def astream(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False) -> AsyncGenerator[Union[str, Dict[str, Any]], None]:
+    async def astream(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False, **extra_kwargs) -> AsyncGenerator[Union[str, Dict[str, Any]], None]:
         """
         True streaming method - yields tokens one by one as they arrive
         
@@ -121,19 +127,19 @@ class OpenAILLMService(BaseLLMService):
             if use_responses_api:
                 logger.info(f"Using Responses API streaming for {self.model_name}")
                 # Use Responses API streaming
-                async for chunk in self._astream_responses_api(input_data, show_reasoning):
+                async for chunk in self._astream_responses_api(input_data, show_reasoning, **extra_kwargs):
                     yield chunk
             else:
                 logger.debug(f"Using Chat Completions API streaming for {self.model_name}")
                 # Use Chat Completions API streaming
-                async for chunk in self._astream_chat_completions_api(input_data):
+                async for chunk in self._astream_chat_completions_api(input_data, **extra_kwargs):
                     yield chunk
                     
         except Exception as e:
             logger.error(f"Error in astream: {e}")
             raise
     
-    async def _astream_responses_api(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False) -> AsyncGenerator[Union[str, Dict[str, Any]], None]:
+    async def _astream_responses_api(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False, **extra_kwargs) -> AsyncGenerator[Union[str, Dict[str, Any]], None]:
         """Stream using Responses API for reasoning models and deep research models"""
         try:
             # Use adapter manager to prepare messages
@@ -228,7 +234,7 @@ class OpenAILLMService(BaseLLMService):
             logger.error(f"Error in _astream_responses_api: {e}")
             raise
     
-    async def _astream_chat_completions_api(self, input_data: Union[str, List[Dict[str, str]], Any]) -> AsyncGenerator[Union[str, Dict[str, Any]], None]:
+    async def _astream_chat_completions_api(self, input_data: Union[str, List[Dict[str, str]], Any], **extra_kwargs) -> AsyncGenerator[Union[str, Dict[str, Any]], None]:
         """Stream using Chat Completions API for standard models"""
         try:
             # Use adapter manager to prepare messages
@@ -242,13 +248,13 @@ class OpenAILLMService(BaseLLMService):
                 "stream": True
             }
             
-            # O4 models only support temperature=1 (default)
-            if not self.is_reasoning_model:
+            # O4 and GPT-5 models only support temperature=1 (default)
+            if not self.requires_default_temperature:
                 kwargs["temperature"] = provider_config.get("temperature", 0.7)
             
-            # O4 models use max_completion_tokens instead of max_tokens
+            # O4 and GPT-5 models use max_completion_tokens instead of max_tokens
             max_tokens_value = provider_config.get("max_tokens", 1024)
-            if self.is_reasoning_model:
+            if self.uses_completion_tokens:
                 kwargs["max_completion_tokens"] = max_tokens_value
             else:
                 kwargs["max_tokens"] = max_tokens_value
@@ -259,6 +265,11 @@ class OpenAILLMService(BaseLLMService):
                 kwargs["tools"] = tool_schemas
                 kwargs["tool_choice"] = "auto"
             
+            # Add response_format if specified (for JSON mode)
+            if 'response_format' in extra_kwargs:
+                kwargs['response_format'] = extra_kwargs['response_format']
+                logger.debug(f"Using response_format in streaming: {extra_kwargs['response_format']}")
+            
             # Stream tokens and detect tool calls
             content_chunks = []
             tool_calls_accumulator = {}  # Track complete tool calls by ID
@@ -360,13 +371,14 @@ class OpenAILLMService(BaseLLMService):
             logger.error(f"Error in _astream_chat_completions_api: {e}")
             raise
     
-    async def ainvoke(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False) -> Union[str, Any]:
+    async def ainvoke(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False, **extra_kwargs) -> Union[str, Any]:
         """
         Unified invoke method for all input types
         
         Args:
             input_data: Input messages or text
             show_reasoning: If True and model supports it, show reasoning process using Responses API
+            **extra_kwargs: Additional parameters to pass to the API (e.g., response_format)
         """
         try:
             # Use adapter manager to prepare messages
@@ -385,13 +397,13 @@ class OpenAILLMService(BaseLLMService):
                 "messages": messages
             }
             
-            # O4 models only support temperature=1 (default)
-            if not self.is_reasoning_model:
+            # O4 and GPT-5 models only support temperature=1 (default)
+            if not self.requires_default_temperature:
                 kwargs["temperature"] = provider_config.get("temperature", 0.7)
             
-            # O4 models use max_completion_tokens instead of max_tokens
+            # O4 and GPT-5 models use max_completion_tokens instead of max_tokens
             max_tokens_value = provider_config.get("max_tokens", 1024)
-            if self.is_reasoning_model:
+            if self.uses_completion_tokens:
                 kwargs["max_completion_tokens"] = max_tokens_value
             else:
                 kwargs["max_tokens"] = max_tokens_value
@@ -403,11 +415,16 @@ class OpenAILLMService(BaseLLMService):
                 if not use_responses_api:  # Responses API handles tool choice differently
                     kwargs["tool_choice"] = "auto"
             
+            # Add response_format if specified (for JSON mode)
+            if 'response_format' in extra_kwargs:
+                kwargs['response_format'] = extra_kwargs['response_format']
+                logger.debug(f"Using response_format: {extra_kwargs['response_format']}")
+            
             # Handle streaming vs non-streaming
             if self.streaming:
                 # TRUE STREAMING MODE - collect all chunks from the stream
                 content_chunks = []
-                async for token in self.astream(input_data, show_reasoning=show_reasoning):
+                async for token in self.astream(input_data, show_reasoning=show_reasoning, **extra_kwargs):
                     if isinstance(token, str):
                         content_chunks.append(token)
                     elif isinstance(token, dict) and "result" in token:
