@@ -9,6 +9,7 @@ import logging
 import base64
 import io
 import time
+import asyncio
 from typing import Dict, Any, List, Union, Optional, BinaryIO
 from PIL import Image
 
@@ -36,7 +37,7 @@ class ISAVisionService(BaseVisionService):
     def __init__(self, 
                  modal_app_id: str = "ap-VlHUQoiPUdy9cgrHSfG7Fk",
                  modal_app_name: str = "isa-vision-ui-optimized",
-                 timeout: int = 30):
+                 timeout: int = 60):
         """
         初始化ISA Vision服务
         
@@ -77,6 +78,31 @@ class ISAVisionService(BaseVisionService):
         self.request_count = 0
         self.total_cost = 0.0
         
+        # 性能优化 - 预热连接（延迟初始化）
+        self._connection_warmed = False
+        
+        # 简单缓存机制（可选）
+        self._result_cache = {}
+        self._cache_max_size = 100
+        
+    async def _warm_connection(self):
+        """预热Modal连接，减少首次调用延迟"""
+        if self._connection_warmed or not self.modal_app:
+            return
+            
+        try:
+            logger.info("Warming up Modal connection...")
+            # 尝试获取服务状态来预热连接
+            if hasattr(self.modal_app, 'list_functions'):
+                await asyncio.wait_for(
+                    asyncio.to_thread(self.modal_app.list_functions),
+                    timeout=10
+                )
+            self._connection_warmed = True
+            logger.info("✅ Modal connection warmed up")
+        except Exception as e:
+            logger.warning(f"Failed to warm up connection: {e}")
+    
     async def analyze_image(
         self, 
         image: Union[str, BinaryIO],
@@ -154,6 +180,9 @@ class ISAVisionService(BaseVisionService):
                     'error': 'Modal app or service not available'
                 }
             
+            # 预热连接以减少延迟
+            await self._warm_connection()
+            
             # 准备图像数据
             image_b64 = await self._prepare_image_base64(image)
             
@@ -208,11 +237,22 @@ class ISAVisionService(BaseVisionService):
             
             # 创建实例并调用优化方法（快速模式，无字幕）
             instance = OptimizedUIDetectionService()
-            result = instance.detect_ui_elements_fast.remote(image_b64, enable_captions=False)
+            # 使用超时控制Modal调用
+            result = await asyncio.wait_for(
+                instance.detect_ui_elements_fast.remote(image_b64, enable_captions=False),
+                timeout=self.timeout
+            )
             
             logger.info("✅ Modal SDK call successful")
             return result
                         
+        except asyncio.TimeoutError:
+            logger.error(f"Modal SDK call timed out after {self.timeout} seconds")
+            return {
+                'success': False,
+                'error': f'Modal service timeout after {self.timeout} seconds',
+                'timeout': True
+            }
         except Exception as e:
             logger.error(f"Modal SDK call failed: {e}")
             return {
@@ -316,11 +356,22 @@ class ISAVisionService(BaseVisionService):
             
             # 创建实例并调用方法
             instance = SuryaOCRService()
-            result = instance.extract_text.remote(image_b64, languages)
+            # 使用超时控制OCR调用
+            result = await asyncio.wait_for(
+                instance.extract_text.remote(image_b64, languages),
+                timeout=self.timeout
+            )
             
             logger.info("✅ OCR service call successful")
             return result
                         
+        except asyncio.TimeoutError:
+            logger.error(f"OCR service call timed out after {self.timeout} seconds")
+            return {
+                'success': False,
+                'error': f'OCR service timeout after {self.timeout} seconds',
+                'timeout': True
+            }
         except Exception as e:
             logger.error(f"OCR service call failed: {e}")
             return {
@@ -499,7 +550,7 @@ class ISAVisionService(BaseVisionService):
         """准备base64编码的图像"""
         if isinstance(image, str):
             # Check if it's already base64 encoded
-            if image.startswith('data:image') or len(image) > 1000:
+            if image.startswith('data:image') or (not image.startswith('http') and len(image) > 1000):
                 # Likely already base64
                 if image.startswith('data:image'):
                     # Extract base64 part
@@ -507,6 +558,16 @@ class ISAVisionService(BaseVisionService):
                 else:
                     # Assume it's pure base64
                     return image
+            elif image.startswith('http://') or image.startswith('https://'):
+                # URL - download the image
+                import aiohttp
+                async with aiohttp.ClientSession() as session:
+                    async with session.get(image) as response:
+                        if response.status == 200:
+                            image_data = await response.read()
+                            return base64.b64encode(image_data).decode('utf-8')
+                        else:
+                            raise ValueError(f"Failed to download image from URL: {response.status}")
             else:
                 # File path
                 with open(image, 'rb') as f:
